<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsBlog extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-blog';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Blog', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-post-content';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'blog-post' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	protected function _register_controls() {



		$this->start_controls_section(

			'section_content_service_post',

			[

				'label' => esc_html__( 'Blog Post', 'bdevs-elementor' ),

			]

		);

		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Type section title here', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

			]

		);

		$this->add_control(

			'number',

			[

				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'3'  => esc_html__( '3', 'bdevs-elementor' ),

					'6' => esc_html__( '6', 'bdevs-elementor' ),

					'9' => esc_html__( '9', 'bdevs-elementor' ),

					'12' => esc_html__( '12', 'bdevs-elementor' ),

					'15' => esc_html__( '15', 'bdevs-elementor' ),

					'18' => esc_html__( '18', 'bdevs-elementor' ),

					'21' => esc_html__( '21', 'bdevs-elementor' ),

				],

				'default'   => '3',

			]

		);



		$this->add_control(

			'orderpost',

			[

				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),

					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),

				],

				'default'   => 'desc',

			]

		);



		$this->add_control(

			'orderby',

			[

				'label'     => esc_html__( 'Order By', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'date'  => esc_html__( 'Date', 'bdevs-elementor' ),

					'title' => esc_html__( 'Title', 'bdevs-elementor' ),

					'rand' => esc_html__( 'Random', 'bdevs-elementor' ),

				],

				'default'   => 'desc',

			]

		);



		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'left',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);			



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	



		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display(); 

		extract($settings); ?>

<section class="news-feed-area pt-115 pb-115">



    <div class="container">



        <div class="row ">



            <div class="col-xl-6 offset-xl-3 col-lg-8 offset-lg-2">



                <div class="section-title text-center mb-70">

                	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

                    <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

                    <?php endif; ?>	

                    <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

                    <p><?php echo wp_kses_post($settings['subheading']); ?></p>

                    <?php endif; ?>	

                </div>



            </div>



        </div>



        <div class="row">

        	<?php 

                $q = new \WP_Query(array(

                    'post_type'     => 'post',

                    'posts_per_page'=> $number,

                    'orderby'       => $orderby,

                    'order'         => $orderpost,

                ));

                    while($q->have_posts()): $q->the_post();  ?>

            <?php $image_home = get_post_meta(get_the_ID(),'_cmb_image_home', true); ?>

            <?php $piohost_redux_demo = get_option('redux_demo'); ?>

            <div class="col-xl-4 col-lg-4 col-md-6">



                <div class="latest-feed mb-45 wow fadeInUp animated" data-wow-delay="0.3s">



                    <div class="news-feed-img">



                        <a href="<?php the_permalink(); ?>"><img src="<?php echo wp_get_attachment_url($image_home);?>" alt=""></a>



                    </div>



                    <div class="news-feed-info">



						<div class="bs-meta">

							<span><i class="far fa-user"></i><?php the_author_posts_link(); ?></span>

							<span><i class="far fa-calendar-check"></i> <?php the_time(get_option( 'date_format' ));?></span>

						</div>



                        <div class="news-feed-titles">



                            <h4><a href="<?php the_permalink(); ?>"><?php the_title();?></a></h4>



                        </div>



                    </div>



                </div>



            </div>

            <?php endwhile; ?>

            



        </div>



        <div class="row mt-60">



            <div class="col-md-12">



                <div class="news-feed-bottom-img">



                    <img src="<?php echo get_template_directory_uri();?>/img/icon/line.png" alt="">



                </div>



            </div>



        </div>



    </div>



</section>

                

	<?php

	}

}