<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsFAQS2 extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-faq2';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'FAQS 2', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-slideshow';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'FAQS 2', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_faqs',

			[

				'label' => esc_html__( 'FAQS', 'bdevs-elementor' ),

			]	

		);

		$this->add_control(

			'background_bg',

			[

				'label'       => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'        => Controls_Manager::MEDIA,

				'dynamic'     => [ 'active' => true ],

				'label_block' => true,

				'description' => esc_html__( 'Upload Background Image', 'bdevs-elementor' ),

			]

		);

		$this->add_control(

			'background_bg2',

			[

				'label'       => esc_html__( 'Image Right', 'bdevs-elementor' ),

				'type'        => Controls_Manager::MEDIA,

				'dynamic'     => [ 'active' => true ],

				'label_block' => true,

				'description' => esc_html__( 'Upload Image Right', 'bdevs-elementor' ),

			]

		);

		$this->add_control(

			'desc',

			[

				'label'       => __( 'Description', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your Description', 'bdevs-elementor' ),

				'default'     => __( 'It is Description', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);		

		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),

				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);		

		$this->add_control(

			'text',

			[

				'label'       => __( 'Text', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Text', 'bdevs-elementor' ),

				'default'     => __( 'It is Text', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'link',

			[

				'label'       => __( 'Link Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),

				'default'     => __( '#', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'button',

			[

				'label'       => __( 'Button', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Button', 'bdevs-elementor' ),

				'default'     => __( 'It is Button', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		

		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		);

		$this->add_control(

			'show_desc',

			[

				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	

		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_text',

			[

				'label'   => esc_html__( 'Show Text', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_button',

			[

				'label'   => esc_html__( 'Show Subtitle', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		



		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		extract($settings);

		?> 

<section class="make-business-area pt-115 pb-90 fix" data-background="<?php print esc_url( $settings['background_bg']['url'] ); ?>">



    <div class="container">



        <div class="row">



          <div class="col-xl-7 col-lg-7 mb-30">



                <div class="faq-wrapper mb-30">



                    <div class="section-title make-business-titles section-title-white mb-70">

                    	<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>

                        <span><?php echo wp_kses_post($settings['desc']); ?></span>

                        <?php endif; ?>

                        <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

                        <h3><?php echo wp_kses_post($settings['heading']); ?></h3>

                        <?php endif; ?>

                        <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

                        <h4><?php echo wp_kses_post($settings['subheading']); ?></h4>

                        <?php endif; ?>



                    </div>



                </div>

                <?php if (( '' !== $settings['text'] ) && ( $settings['show_text'] )) : ?>

                <div class="make-business">



                     <ul>

                     	

	                    <?php echo wp_kses_post($settings['text']); ?>



                     </ul>



                </div>

                <?php endif; ?>

                <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>

                <div class="make-btn">



                    <a href="<?php echo wp_kses_post($settings['link']); ?>" class="btn btn-soft-border"><?php echo wp_kses_post($settings['button']); ?></a>



                </div>

                <?php endif; ?>

            </div>



            <div class="col-xl-5 col-lg-5">



                <div class="faq-img make-business-img mb-30">



                    <img class="bounce-animate" src="<?php print esc_url( $settings['background_bg2']['url'] ); ?>" alt="">



                </div>



            </div>



        </div>



    </div>



</section>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $("[data-background]").each(function () {
	$(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
})
        
        
    </script>   
    <?php } ?>
	<?php

	}



}

