<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsPricing3 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-pricing3';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing 3', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'pricing3' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_pricing',
			[
				'label' => esc_html__( 'Pricing', 'bdevs-elementor' ),
			]	
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'monthly_plan',
			[
				'label'       => __( 'Monthly Plan', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Monthly Plan', 'bdevs-elementor' ),
				'default'     => __( 'Monthly Plan', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'yearly_plan',
			[
				'label'       => __( 'Yearly Plan', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Yearly Plan', 'bdevs-elementor' ),
				'default'     => __( 'Yearly pricing for save -35% ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->end_controls_section();
		$this->start_controls_section(
			'section_content_monthly',
			[
				'label' => esc_html__( 'Monthly Plan', 'bdevs-elementor' ),
			]	
		);
		$this->add_control(
			'price_sidebar',
			[
				'label'       => __( 'Price Sidebar', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Price Plan', 'bdevs-elementor' ),
				'default'     => __( 'It is Price Plan', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Monthly Plan', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'title'   => esc_html__( 'Title', 'bdevs-elementor' ),
						'content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( ' Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( ' Title Items' , 'bdevs-elementor' ),
						'label_block' => true,
					],				
					[
						'name'        => 'pricing',
						'label'       => esc_html__( 'Pricing Items', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Create Account' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'desc',
						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);
		

		$this->end_controls_section();
		$this->start_controls_section(
			'section_content_yearly',
			[
				'label' => esc_html__( 'Yearly Plan', 'bdevs-elementor' ),
			]	
		);
		$this->add_control(
			'price_sidebar2',
			[
				'label'       => __( 'Price Sidebar', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Price Plan', 'bdevs-elementor' ),
				'default'     => __( 'It is Price Plan', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Yearly Plan', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'title'   => esc_html__( 'Title', 'bdevs-elementor' ),
						'content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( ' Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( ' Title Items' , 'bdevs-elementor' ),
						'label_block' => true,
					],				
					[
						'name'        => 'pricing',
						'label'       => esc_html__( 'Pricing Items', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Create Account' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'desc',
						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);
		

		$this->end_controls_section();
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);
		

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_monthly_plan',
			[
				'label'   => esc_html__( 'Show Monthly Plan', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_yearly_plan',
			[
				'label'   => esc_html__( 'Show Yearly Plan', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_price_sidebar',
			[
				'label'   => esc_html__( 'Show Pricing Sidebar Monthly', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_price_sidebar2',
			[
				'label'   => esc_html__( 'Show Pricing Sidebar Yearly', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_pricing',
			[
				'label'   => esc_html__( 'Show Pricing', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);
	?> 
<div class="price-area pt-110 pb-90">

    <div class="container">

        <div class="row ">

            <div class="col-xl-6 offset-xl-3 col-lg-8 offset-lg-2">

                <div class="section-title text-center mb-70">

                    <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
                    <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                    <?php endif; ?>
                    <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
                    <p><?php echo wp_kses_post($settings['subheading']); ?></p>
                    <?php endif; ?>

                </div>

            </div>

        </div>

        <div class="row">

            <div class="col-12">

                <ul class="nav price-tabs mb-50" id="myTab" role="tablist">
                	<?php if (( '' !== $settings['monthly_plan'] ) && ( $settings['show_monthly_plan'] )) : ?>
                    <li class="nav-item">

                        <a class="nav-link active" id="home-tab" data-toggle="tab" href="#home" role="tab"

                            aria-controls="home" aria-selected="true"><?php echo wp_kses_post($settings['monthly_plan']); ?><i class="fal fa-angle-left"></i></a>

                    </li>
                    <?php endif; ?>
                    <?php if (( '' !== $settings['yearly_plan'] ) && ( $settings['show_yearly_plan'] )) : ?>
                    <li class="nav-item">

                        <a class="nav-link" id="profile-tab" data-toggle="tab" href="#profile" role="tab"

                            aria-controls="profile" aria-selected="false"><?php echo wp_kses_post($settings['yearly_plan']); ?><i

                                class="fal fa-angle-left"></i></a>

                    </li>
                    <?php endif; ?>
                </ul>

                <div class="tab-content" id="myTabContent">
                	
                    <div class="tab-pane fade show active" id="home" role="tabpanel" aria-labelledby="home-tab">

                        <div class="row no-gutters">
                        	<?php if (( '' !== $settings['price_sidebar'] ) && ( $settings['show_price_sidebar'] )) : ?>
                            <div class="col-xl-3 col-lg-3 col-mg-4 d-none d-lg-block">

                                <div class="price-sidebar mb-30">

                                    <ul>

                                        <?php echo wp_kses_post($settings['price_sidebar']); ?>

                                    </ul>

                                </div>

                            </div>
                            <?php endif; ?>
                            <?php
					    	$idd = 0;
					    	 foreach ( $settings['tabs'] as $item ) :
					    	 $idd++;
					    	  ?>

                            <div class="col-xl-3 col-lg-3 col-mg-4">
                            	<?php if ($idd=='2') { ?>
                                <div class="price-wrapper active text-center mb-30">
                                <?php } else { ?>
                                <div class="price-wrapper text-center mb-30">
                                <?php } ?>
                                    <div class="price-details">
                                    	<?php if (( '' !== $item['title'] ) && ( $settings['show_title'] )) : ?>
                                        <span><?php echo wp_kses_post($item['title']); ?></span>
                                        <?php endif; ?>
                                        <?php if (( '' !== $item['pricing'] ) && ( $settings['show_pricing'] )) : ?>
                                        <h4 class="price"><?php echo wp_kses_post($item['pricing']); ?></h4>
                                        <?php endif; ?>
                                        <?php if (( '' !== $item['button'] ) && ( $settings['show_button'] )) : ?>
                                        <a class="btn price-btn" href="<?php echo wp_kses_post($item['link']); ?>"><?php echo wp_kses_post($item['button']); ?></a>
                                        <?php endif; ?>
                                    </div>
                                    <?php if (( '' !== $item['desc'] ) && ( $settings['show_desc'] )) : ?>
                                    <ul class="price-content">
                                       <?php echo wp_kses_post($item['desc']); ?>
                                    </ul>
                                    <?php endif; ?>
                                </div>

                            </div>
                            <?php
							endforeach;
							?>
                            

                        </div>

                    </div>
                    



                    <div class="tab-pane fade" id="profile" role="tabpanel" aria-labelledby="profile-tab">

                        <div class="row no-gutters">
                        	<?php if (( '' !== $settings['price_sidebar2'] ) && ( $settings['show_price_sidebar2'] )) : ?>
                            <div class="col-xl-3 col-lg-3 col-mg-4 d-none d-lg-block">

                                <div class="price-sidebar mb-30">

                                    <ul>

                                        <?php echo wp_kses_post($settings['price_sidebar2']); ?>

                                    </ul>

                                </div>

                            </div>
                            <?php endif; ?>
                            <?php
					    	$idd = 0;
					    	 foreach ( $settings['tabs2'] as $item ) :
					    	 $idd++;
					    	  ?>
                            

                            <div class="col-xl-3 col-lg-3 col-mg-4">
                            	<?php if ($idd=='2') { ?>
                                <div class="price-wrapper active text-center mb-30">
                                <?php } else { ?>
                                <div class="price-wrapper text-center mb-30">
                                <?php } ?>

                                    <div class="price-details">
                                    	<?php if (( '' !== $item['title'] ) && ( $settings['show_title'] )) : ?>
                                        <span><?php echo wp_kses_post($item['title']); ?></span>
                                        <?php endif; ?>
                                        <?php if (( '' !== $item['pricing'] ) && ( $settings['show_pricing'] )) : ?>
                                        <h4 class="price"><?php echo wp_kses_post($item['pricing']); ?></h4>
                                        <?php endif; ?>
                                        <?php if (( '' !== $item['title'] ) && ( $settings['show_title'] )) : ?>
                                        <a class="btn price-btn" href="<?php echo wp_kses_post($item['link']); ?>"><?php echo wp_kses_post($item['button']); ?></a>
                                        <?php endif; ?>
                                    </div>
                                    <?php if (( '' !== $item['desc'] ) && ( $settings['show_desc'] )) : ?>
                                    <ul class="price-content">
                                        <?php echo wp_kses_post($item['desc']); ?>
                                    </ul>
                                    <?php endif; ?>

                                </div>

                            </div>

                            <?php
							endforeach;
							?>

                        </div>

                    </div>

                </div>

            </div>

        </div>

    </div>

</div>
	<?php
	}

}