<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsTeam extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-team';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Team', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-slideshow';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'Team', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_Team',

			[

				'label' => esc_html__( 'Team', 'bdevs-elementor' ),

			]	

		);

		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Team', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'default' => [

					[

						'tab_title'   => esc_html__( 'Team', 'bdevs-elementor' ),

						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),

					]

				],

				'fields' => [

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Image Team', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

						

					],

					[

						'name'    => 'tab_image2',

						'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

						

					],

					[

						'name'        => 'name',

						'label'       => esc_html__( ' Name', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Name' , 'bdevs-elementor' ),

						'label_block' => true,

					],	

					[

						'name'        => 'job',

						'label'       => esc_html__( ' Job', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Job' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'desc',

						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'facebook',

						'label'       => esc_html__( 'Link Facebook', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'twitter',

						'label'       => esc_html__( 'Link Twitter', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'behance',

						'label'       => esc_html__( 'Link Behance', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'youtube',

						'label'       => esc_html__( 'Link Youtube', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'linkedin',

						'label'       => esc_html__( 'Link linkedin', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '#' , 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);

		

		$this->end_controls_section();



		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		);

		$this->add_control(

			'show_name',

			[

				'label'   => esc_html__( 'Show Name', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);	

		$this->add_control(

			'show_job',

			[

				'label'   => esc_html__( 'Show Job', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->add_control(

			'show_desc',

			[

				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_facebook',

			[

				'label'   => esc_html__( 'Show Facebook', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_twitter',

			[

				'label'   => esc_html__( 'Show Twitter', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_behance',

			[

				'label'   => esc_html__( 'Show Behance', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_youtube',

			[

				'label'   => esc_html__( 'Show Youtube', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_linkedin',

			[

				'label'   => esc_html__( 'Show Linkedin', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		extract($settings);

		?> 

<div class="our-team-area pt-110 pb-90">

    <div class="container">

        <div class="row">

            

            <?php

        	$idd = 0;

        	 foreach ( $settings['tabs'] as $item ) :

        	 $idd++;

        	  ?>

            <div class="col-xl-4 col-lg-4 col-md-6">

                <div class="our-team-wrapper mb-30 wow fadeInUp" data-wow-delay=".7s">

                    <div class="team-img position-relative">

                        <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt="">

                        <div class="team-shape shape<?php echo esc_attr($idd);?>">

                            <img src="<?php print esc_url($item['tab_image2']['url']); ?>" alt="">

                        </div>

                    </div>

                    <div class="team-text">

                    	<?php if (( '' !== $item['name'] ) && ( $settings['show_name'] )) : ?>

                        <h2><?php echo wp_kses_post($item['name']); ?></h2>

                        <?php endif; ?>

                        <?php if (( '' !== $item['job'] ) && ( $settings['show_job'] )) : ?>

                        <span><?php echo wp_kses_post($item['job']); ?></span>

                        <?php endif; ?>

                        <?php if (( '' !== $item['desc'] ) && ( $settings['show_desc'] )) : ?>

                        <p><?php echo wp_kses_post($item['desc']); ?></p>

                        <?php endif; ?>

                        <div class="team-link">

                            <ul>

                            	<?php if (( '' !== $item['facebook'] ) && ( $settings['show_facebook'] )) : ?>

                                <li><a href="<?php echo wp_kses_post($item['facebook']); ?>"><i class="fab fa-facebook-f"></i></a></li>

                                <?php endif; ?>

                                <?php if (( '' !== $item['twitter'] ) && ( $settings['show_twitter'] )) : ?>

                                <li><a href="<?php echo wp_kses_post($item['twitter']); ?>"><i class="fab fa-twitter"></i></a></li>

                                <?php endif; ?>

                                <?php if (( '' !== $item['behance'] ) && ( $settings['show_behance'] )) : ?>

                                <li><a href="<?php echo wp_kses_post($item['behance']); ?>"><i class="fab fa-behance"></i></a></li>

                                <?php endif; ?>

                                <?php if (( '' !== $item['youtube'] ) && ( $settings['show_youtube'] )) : ?>

                                <li><a href="<?php echo wp_kses_post($item['youtube']); ?>"><i class="fab fa-youtube"></i></a></li>

                                <?php endif; ?>

                                <?php if (( '' !== $item['linkedin'] ) && ( $settings['show_linkedin'] )) : ?>

                                <li><a href="<?php echo wp_kses_post($item['linkedin']); ?>"><i class="fab fa-linkedin"></i></a></li>

                                <?php endif; ?>

                            </ul>

                        </div>

                    </div>

                </div>

            </div>

            <?php

			endforeach;

			?>

            

        </div>

    </div>

</div>

	<?php

	}



}

