<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsTestimonial extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-testimonial';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Testimonial', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'testimonial' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_testimonial',

			[

				'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),

			]	

		);



		$this->add_control(

			'subheading',

			[

				'label'       => __( 'Subheading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),

				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);		



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Testimonial Item', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'default' => [

					[

						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),

						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),

					]

				],

				'fields' => [

					[

						'name'        => 'star',

						'label'       => esc_html__( 'Star', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( ' Star' , 'bdevs-elementor' ),

						'label_block' => true,

					],	

					[

						'name'        => 'domain',

						'label'       => esc_html__( 'Domain', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Design Quality' , 'bdevs-elementor' ),

						'label_block' => true,

					],	

					[

						'name'        => 'desc',

						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),

						'label_block' => true,

					],	

					[

						'name'        => 'tab_image',

						'type'        => Controls_Manager::MEDIA,

						'dynamic'     => [ 'active' => true ],

						'label_block' => true,

						'description' => esc_html__( 'Upload avatar', 'bdevs-elementor' ),
						'default'     => __( '', 'bdevs-elementor' ),

					],	

					[

						'name'        => 'name',

						'label'       => esc_html__( 'Name', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Cherlyn Ruddick' , 'bdevs-elementor' ),

						'label_block' => true,

					],				

					[

						'name'        => 'job',

						'label'       => esc_html__( 'Job', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXT,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( 'Founder, Google' , 'bdevs-elementor' ),

						'label_block' => true,

					],				



					

				],

			]

		);

		



		$this->end_controls_section();



		/** 

		*	Layout section 

		**/

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		);



		$this->add_control(

			'show_heading',

			[

				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);			



		$this->add_control(

			'show_subheading',

			[

				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->add_control(

			'show_star',

			[

				'label'   => esc_html__( 'Show Star', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);





		$this->add_control(

			'show_domain',

			[

				'label'   => esc_html__( 'Show Domain', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_desc',

			[

				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_tab_image',

			[

				'label'   => esc_html__( 'Show Avatar', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_name',

			[

				'label'   => esc_html__( 'Show Name', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_job',

			[

				'label'   => esc_html__( 'Show Job', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display();

		extract($settings);

	?> 

<section class="testimonail-area grad-bg pt-115 pb-120">



    <div class="container">



        <div class="row">



            <div class="col-xl-6 col-lg-8">



                <div class="section-title section-title-white mb-70">

                	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>

                    <h2><?php echo wp_kses_post($settings['heading']); ?></h2>

                    <?php endif; ?>

                    <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>

                    <p><?php echo wp_kses_post($settings['subheading']); ?></p>

                    <?php endif; ?>

                </div>



            </div>



        </div>



        <div class="row activ-testimonai wow fadeInUp animated" data-wow-delay="0.3s">



        	<?php

        	$idd = 0;

        	 foreach ( $settings['tabs'] as $item ) :

        	 $idd++;

        	  ?>



            <div class="col-xl-12">



                <div class="testimonail-wraper mb-30">



                    <div class="testimonail-titles">

                    	<?php if (( '' !== $item['star'] ) && ( $settings['show_star'] )) : ?>

                        <div class="testimonail-icon">

						<?php echo wp_kses_post($item['star']); ?>

                        </div>

                        <?php endif; ?>

                        <?php if (( '' !== $item['domain'] ) && ( $settings['show_domain'] )) : ?>

                        <span><?php echo wp_kses_post($item['domain']); ?></span>

                        <?php endif; ?>

                    </div>

                    <?php if (( '' !== $item['desc'] ) && ( $settings['show_desc'] )) : ?>

                    <p><?php echo wp_kses_post($item['desc']); ?></p>

                    <?php endif; ?>

                    <div class="testimonail-author">

                    	<?php if (( '' !== $item['tab_image'] ) && ( $settings['show_tab_image'] )) : ?>

                        <div class="testimonail-img">



                            <img src="<?php print esc_url($item['tab_image']['url']); ?>" alt="">



                        </div>

                        <?php endif; ?>

                        <?php if (( '' !== $item['name'] ) && ( $settings['show_name'] )) : ?>

                        <h5><?php echo wp_kses_post($item['name']); ?></h5>

                        <?php endif; ?>

                         <?php if (( '' !== $item['job'] ) && ( $settings['show_job'] )) : ?>

                        <span><?php echo wp_kses_post($item['job']); ?></span>

                        <?php endif; ?>

                    </div>



                </div>



            </div>

            <?php

			endforeach;

			?>

        </div>



    </div>



</section>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.activ-testimonai').slick({
   dots: false,
   arrows: true,
   infinite: true,
   speed: 300,
   slidesToShow: 3,
   slidesToScroll: 1,
   prevArrow:'<button type="button" class="slick-prev"><i class="fas fa-arrow-left"></i></button>',
	 nextArrow:'<button type="button" class="slick-next"><i class="fas fa-arrow-right"></i></button>',
	centerMode: true,
	centerPadding: '0',
  responsive: [
    {
      breakpoint: 1200,
      settings: {
        slidesToShow: 2,
        slidesToScroll:1,
        infinite: true,
        dots: false,
        centerMode: false,
      }
    },
    {
      breakpoint: 992,
      settings: {
        slidesToShow: 2,
        slidesToScroll: 1,
        arrows: false,
        centerMode: false,
      }
    },
    {
      breakpoint: 767,
      settings: {
        slidesToShow: 1,
        slidesToScroll: 1,
        arrows: false,
      }
    }
  ]
});
        
        
    </script>   
    <?php } ?>
	<?php

	}



}