<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class BdevsTestimonial2 extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'bdevs-testimonial2';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Testimonial 2', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'bdevs-elementor' ];

	}



	public function get_keywords() {

		return [ 'testimonial' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_content_testimonial',

			[

				'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),

			]	

		);

		$this->add_control(

			'background_bg',

			[

				'label'       => esc_html__( 'Background Image', 'bdevs-elementor' ),

				'type'        => Controls_Manager::MEDIA,

				'dynamic'     => [ 'active' => true ],

				'label_block' => true,

				'description' => esc_html__( 'Upload Background Image', 'bdevs-elementor' ),

			]

		);	

		$this->add_control(

			'star',

			[

				'label'       => __( 'star', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your star', 'bdevs-elementor' ),

				'default'     => __( 'star', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);		



		$this->add_control(

			'domain',

			[

				'label'       => __( 'Domain', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your Domain', 'bdevs-elementor' ),

				'default'     => __( '“ Design Quality ”', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'title',

			[

				'label'       => __( 'Title', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your Title', 'bdevs-elementor' ),

				'default'     => __( 'It is Title', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'subtitle',

			[

				'label'       => __( 'Subtitle', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Subtitle', 'bdevs-elementor' ),

				'default'     => __( 'It is Subtitle', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'background_bg2',

			[

				'label'       => esc_html__( 'Avatar', 'bdevs-elementor' ),

				'type'        => Controls_Manager::MEDIA,

				'dynamic'     => [ 'active' => true ],

				'label_block' => true,

				'description' => esc_html__( 'Upload Avatar', 'bdevs-elementor' ),

			]

		);	

		$this->add_control(

			'name',

			[

				'label'       => __( 'Name', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your Name', 'bdevs-elementor' ),

				'default'     => __( 'It is Name', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	

		$this->add_control(

			'job',

			[

				'label'       => __( 'Job', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Enter your Job', 'bdevs-elementor' ),

				'default'     => __( 'Founder, Google', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->end_controls_section();



		/** 

		*	Layout section 

		**/

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		);



		$this->add_control(

			'show_star',

			[

				'label'   => esc_html__( 'Show Star', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);			



		$this->add_control(

			'show_domain',

			[

				'label'   => esc_html__( 'Show Domain', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);		



		$this->add_control(

			'show_title',

			[

				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);





		$this->add_control(

			'show_subtitle',

			[

				'label'   => esc_html__( 'Show Subtitle', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_background_bg',

			[

				'label'   => esc_html__( 'Show Avatar', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_name',

			[

				'label'   => esc_html__( 'Show Name', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);

		$this->add_control(

			'show_job',

			[

				'label'   => esc_html__( 'Show Job', 'bdevs-elementor' ),

				'type'    => Controls_Manager::SWITCHER,

				'default' => 'yes',

			]

		);



		$this->end_controls_section();



	}



	public function render() {

		$settings  = $this->get_settings_for_display();

		extract($settings);

		?> 

<section class="testimonail-area testimonail-border">



    <div class="container">



        <div class="row">



             <div class="col-xl-5 col-lg-5 d-flex align-items-end">



                  <div class="testimoinal-img mt-25">



                       <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" alt="">



                  </div>



             </div>



            <div class="col-xl-6 col-lg-7 offset-xl-1">



                <div class="testimonail-area-three">



                    <div class="testimonail-titles">

                    	<?php if (( '' !== $settings['star'] ) && ( $settings['show_star'] )) : ?>

                        <div class="testimonail-icon">

                            <?php echo wp_kses_post($settings['star']); ?>

                        </div>

                        <?php endif; ?>

                        <?php if (( '' !== $settings['domain'] ) && ( $settings['show_domain'] )) : ?>

                        <span><?php echo wp_kses_post($settings['domain']); ?></span>

                        <?php endif; ?>

                    </div>

                    <?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>

                    <h4><?php echo wp_kses_post($settings['title']); ?></h4>

                    <?php endif; ?>

                    <?php if (( '' !== $settings['subtitle'] ) && ( $settings['show_subtitle'] )) : ?>

                    <p><?php echo wp_kses_post($settings['subtitle']); ?></p>

                    <?php endif; ?>



                    <div class="testimonail-author">

                    	

                        <div class="testimonail-img">



                            <img src="<?php print esc_url( $settings['background_bg2']['url'] ); ?>" alt="">



                        </div>

                        

                        <?php if (( '' !== $settings['name'] ) && ( $settings['show_name'] )) : ?>

                        <h5><?php echo wp_kses_post($settings['name']); ?></h5>

                        <?php endif; ?>

                        <?php if (( '' !== $settings['job'] ) && ( $settings['show_job'] )) : ?>

                        <span><?php echo wp_kses_post($settings['job']); ?></span>

                        <?php endif; ?>

                    </div>



                </div>



            </div>



        </div>



    </div>



</section>

	<?php

	}



}